@@ -7,8 +7,12 @@ skip_if_no_redis <- function() {
 }
 
 skip_if_no_couchdb <- function() {
+  COUCHDB_TEST_USER <- Sys.getenv("COUCHDB_TEST_USER")
+  COUCHDB_TEST_PWD <- Sys.getenv("COUCHDB_TEST_PWD")
   testthat::skip_if_not_installed("sofa")
-  if (inherits(try(src_couchdb(), silent = TRUE), "try-error")) {
+  if (inherits(try(
+    src_couchdb(user=COUCHDB_TEST_USER, pwd=COUCHDB_TEST_PWD), 
+      silent = TRUE), "try-error")) {
     skip("couchdb is not available")
   }
 }
